#
# spec file for package pithos
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2012-2014 Malcolm J Lewis <malcolmlewis@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global appid io.github.Pithos
Name:           pithos
Version:        1.6.0
Release:        1.8
Summary:        Native Pandora Radio client for Linux
License:        GPL-3.0-only
Group:          Productivity/Multimedia/Other
URL:            https://pithos.github.io
Source0:        https://github.com/pithos/pithos/releases/download/%{version}/pithos-%{version}.tar.xz
# Needed for automatic typelib() Requires.
BuildRequires:  gobject-introspection
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  meson >= 0.50.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(python3) >= 3.4
Requires:       gstreamer-plugins-bad
Requires:       gstreamer-plugins-good
Requires:       python3-cairo
Requires:       python3-gobject-Gdk
# Implementation of secret service
Recommends:     gnome-keyring
BuildArch:      noarch

%description
Pithos is a native Pandora Radio client for Linux. It's much more
lightweight than the Pandora.com web client, and integrates with desktop
features such as media keys, notifications, and the sound menu.

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install

# Fix boo#1110032 - Create noarch pyc files
find %{buildroot} -name \*.pyc -delete
%py3_compile %{buildroot}

# Remove unnecessary icons
rm -rf %{buildroot}%{_datadir}/icons/ubuntu-mono*

%files
%license license
%doc README.md
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/icons/hicolor/
%{_datadir}/metainfo/%{appid}.appdata.xml
%dir %{_datadir}/dbus-1
%dir %{_datadir}/dbus-1/services
%{_datadir}/dbus-1/services/%{appid}.service
%{_mandir}/man1/pithos.1%{?ext_man}

%changelog
* Mon Dec  5 2022 Dirk Müller <dmueller@suse.com>
- Update to version 1.6.0:
  + This is a fairly small release with some UI tweaks and bug
    fixes:
  - Use a headerbar for main window.
  - Add Ctrl+r shortcut to open stations popover.
  - Remove access to host keyring when in flatpak.
  - notification_icon: Remove dependency on libappindicator.
    StatusNotifier is directly supported but XEmbed trays are no
    longer supported.
* Sat Oct  2 2021 Enrico Belleri <idesmi@protonmail.com>
- Update to 1.5.1:
  * Add Quit to the app menu
  * Remove the limit of 95 stations
  * Handle Enter keypress in stations search
  * Fix app menu keybindings failing to work
  * Fix syntax error on Python 3.8
  * Fix an exception on newer versions of pygobject
  * Fix album art downloads in Flatpak
  * MPRIS: Fix media keys failing to bind on KDE
* Tue Oct 22 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.5.0:
  + This is a relatively small release fixing appmenu integration
    on modern versions of GNOME as well as using more sandbox
    (Flatpak) friendly APIs. Note that this move may introduce
    behavior changes on some platforms.
  + Remove appmenu and move into a menu button in the toolbar.
  + Fix preference dialog accidentally getting destroyed.
  + Notify: Migrate to GNotification.
  + MPRIS: Rename name to match app-id
    (org.mpris.MediaPlayer2.io.github.Pithos).
  + Screensaver Pause: Remove platform specific screensaver support
    and use GTK's built-in detection.
- Drop pithos-fix-deprecated-pygobject.patch: Fixed upstream.
- Drop post(un) handling of glib2_gsettings_schema_post(un),
  desktop_database_post(un) and icon_theme_cache_post(un), no
  longer needed for any supported version of openSUSE.
- Drop update-desktop-files BuildRequires and macro, no longer
  needed.
* Tue May 28 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Create noarch pyc files (boo#1110032)
* Sat Aug 18 2018 bjorn.lie@gmail.com
- Update to version 1.4.1:
  + Change default quality to high (mp3)
  + Mark application as DBusActivatable
  + MPRIS: Fix potential unhandled exception
  + Mediakeys: Handle keyboards with a dedicated pause key
  + Mediakeys: Fix support on GNOME-Shell 3.26+ and MATE
  + Notify: Improve behavior on various notification servers
- Changes from version 1.4.0:
  + Add new plugin that inhibits screensaver/suspend during
    playback
  + Add new plugin adding a 10-band equalizer
  + Add new plugin that automatically normalizes volume between
    tracks
  + Add help entry (F1) that opens the wiki
  + Replace build system with Meson
  + Automatically detect if the user has Pandora One
  + Improve saving and restoring window position
  + Improve plugin loading performance and error reporting
  + Notification Icon: Improve detecting if a tray is available
  + Notification Icon: Add option to use symbolic icon
- Changes from version 1.3.1:
  + Fix exception on Python 3.6+
  + Add ability to create stations based upon current song/artist
  + Show useful error on renaming Thumbprint Radio
  + Show useful error on creating already existing station
  + Minor buffering improvements
  + lastfm: Improve preferences and offer to deauthorize account
  + mpris: Add extension for ratings and remove legacy interface
  + mediakeys: Fix on future versions of GNOME 3.24.2+
  + mediakeys: Avoid using keybinder on Wayland (old keybinder
    would crash)
- Changes from version 1.3.0:
  + Add support for MPRIS TrackList and PlayList interface
  + Add dynamic rating and cover icons based upon theme colors
  + Add plugin for logging to systemd journal
  + Add symbolic icon
  + Add man page
  + Improve handling playlist expiration
  + Improve search in stations list
  + Improve accessibility of UI
  + Improve buffering behavior
  + Improve libsecret support
  + Remove dependency on libnotify
  + Fix disabling keybindings plugin when using keybinder
  + Fix notification icon trying to load on Wayland
  + Fix failure to reconnect on login expiration
  + Fix some plugins not being enabled by default
  + Fix handling error on MPRIS plugin failure
  + Fix migrating configs from < 0.3.18
- Switch to meson buildsystem, add meson BuildRequires and
  corresponding macros.
- Add pithos-fix-deprecated-pygobject.patch: Fix deprecated
  PyGObject usage.
- Conditionalize post(un) handling, no longer needed for modern
  versions of openSUSE.
- Drop fdupes BuildRequires and macro, no longer needed.
* Thu Aug  4 2016 dimstar@opensuse.org
- Replace python3-gobject Requires with python3-gobject-Gdk since
  this was split for X-less setups, but pitos uses Gdk features.
* Wed Aug  3 2016 tingping@fedoraproject.org
- Update to 1.2.1:
  + Show a useful error dialog if no secret service found
  + Improvements to handling login credential changes
  + Fix icon name for main window
  + notification_icon: Fix visible toggle with AppIndicator going out of sync
  + mpris: Fix GetCurrentSong() in legacy interface
- Changes from 1.2.0:
  + Migrate build system to Autotools
  + Migrate settings to GSettings
  + Store password with SecretService (libsecret)
  + Remove all dependencies on dbus-python
  + Add extensive keyboard shortcuts for the main window
    + Add Keyboard Shortcuts help window on Gtk 3.20+
  + Add initial support for translations (translators needed!)
  + Add explicit content filter option
  + Fix high CPU usage with Ubuntu's default theme
  + Redesign all dialogs to use Headerbars
  + Redesign stations dropdown as a Popover with searching and sorting
  + Improve integration with Flatpak
    + Use Gio to open URIs
    + Rename icons and data files to match app id
  + mpris:
    + Effectively rewritten to better follow the spec
    + Reference album art as locally downloaded files
  + notify: Fix Ubuntu sometimes showing wrong art
  + lastfm: Fix now playing not being set
- Changes from 1.1.2:
  + Fix SSL error with Pandora One
  + Fix pacparser usage
  + Fix PyGObject 3.18+ warnings
  + notify: Fix album art not showing up
  + notification_icon:
    + Always use AppIndicator if installed (Fixes KDE 5, Elementary)
    + Add scroll to change volume with AppIndicator
    + Toggle visibility on middle  +click with AppIndicator
  + mediakeys: Add support for DBUS bindings on MATE
  + lastfm: Don't scrobble ads
- Changes from 1.1.1:
  + Fix erratic buffering behavior
  + Clarified license in Readme
  + Add explicit version check for Gtk 3.14
- Changes from 1.1.0:
  + Redesign plugin preferences (Now requires Gtk 3.14)
  + Fix locking up when buffering a song (#94)
  + Make lastfm an optional plugin
  + Make MPRIS an optional plugin
  + Update various icons
  + Minor performance improvements
  + MPRIS: Add property introspection
  + MPRIS: Add song rating `pithos:rating`
  + Notify: Fix escaping text when not needed
- Update Url
- Specify required Python version
- Change depedencies for current release
- Change build system for autotools
- Change data file references to new app id
* Tue Apr  5 2016 dimstar@opensuse.org
- Call fdupes only over pyton3_sitelib: ensure that
  /usr/share/icons contains actual files and not symlinks.
* Sun Nov 30 2014 malcolmlewis@opensuse.org
- Update to version 1.0.1:
  + Automatically install missing codecs if supported.
  + Save window position between sessions.
  + Fix saving last station on quit.
  + Fix pacparser support.
  + Improve pandora module docs.
  + Add setup.py command to build docs.
  + Add appdata file.
  + Notification_icon: Make toggling visibility more reliable.
  + mpris: Fix exception when querying positon.
  + mpris: Implement setting volume.
- Update fixes Pandora stream and hangs at "loading songs" This
  occurs randomly, sometimes very frequently (boo#907701).
* Tue Aug  5 2014 malcolmlewis@opensuse.org
- Update to version 1.0.0:
  + Move to Python 3, Gtk3 and GStreamer 1.0.
  + Fix issue causing large amounts of buffering.
  + Add indication when songs are replaced by ads.
  + Add bitrate to song description.
  + Add new icon.
  + Add playback controls to notifications.
  + Add support for Proxy Auto-Config
- Changes from version 0.3.18:
  + Fix high quality setting.
  + Fix screensaver_pause plugin on DE's other than Gnome.
  + Fix fake client.
  + Pause playback when space is pressed.
  + Implement the rest of MPRIS 2.2.
  + No longer bundle pylast.
  + Have gstreamer respect proxy.
  + Move to setuptools.
- Update Url.
- Update python-devel, python-desturils-extra and python-setuptools
  with their respective python3-* BuildRequires: follow the port to
  python3.
- Replace gstreamer-0_10-* BuildRequires with the GStreamer 1.0
  related gstreamer-* counterparts.
- Drop obsolete openSUSE version checks from spec.
- Add gobject-introspection BuildRequires for automatic typelib()-
  Requires.
- Drop python-gtk and python-notify Requires: no longer required.
* Tue May 22 2012 dimstar@opensuse.org
- Change license to be GPL-3.0, as per legal review (bnc#763416).
* Fri May  4 2012 malcolmlewis@opensuse.org
- Update to version 0.3.17:
  + Switch to JSON API to work around XMLRPC API update
    (lp#988395).
  + Fix rename station menu item.
  + Update FSF address in pylast.py (lp#987883).
  + Remove #! header from files that are not executable
    (lp#988364).
- Drop pithos-fix-incorrect-fsf-address.patch: fixed upstream.
- Drop pithos-fix-non-executable-script.patch: fixed upstream.
* Wed Apr 25 2012 malcolmlewis@opensuse.org
- Updated to new version 0.3.16:
  + Numerous bugfixes.
  + Minor User Interface improvements.
- Add pithos-fix-incorrect-fsf-address.patch: Fix incorrect FSF
  address (lp#987883).
- Add pithos-fix-non-executable-script.patch: Fix file contains a
  shebang (lp#988364).
* Sat Apr 14 2012 malcolmlewis@opensuse.org
- New bzr version now at revision 202:
  + Tweaks to prefs dialog.
  + Pass album art URL to MPRIS for Unity sound menu (lp#876984).
  + Add "Quit" item to menu (lp#904589).
  + Better handling of fatal gstreamer codec errors.
  + Add "Player" to category to allow build on openSUSE Open Build
    service (lp#976327).
  + Handle urllib HTTPError.
- Drop pithos-fix-no-sufficient-category-definition.patch as this
  has been upstreamed.
* Sun Apr  8 2012 malcolmlewis@opensuse.org
- Initial build.
- Add pithos-fix-no-sufficient-category-definition.patch: Add
  Player to categories in desktop file (lp#976327).
